@@ -1,24 +1,23 @@
 #!/bin/false
+# ABSTRACT: A client for the Bugzilla web services API.
+# PODNAME: BZ::Client
 
-#
-# BZ::Client.pm - Web services client for the Bugzilla server
-#
+use strict;
+use warnings 'all';
 
 package BZ::Client;
-
+$BZ::Client::VERSION = '1.063';
 use BZ::Client::XMLRPC();
 use HTTP::Cookies();
 
-our $VERSION = '1.061';
-
-sub new($%) {
+sub new {
     my $class = shift;
     my $self  = {@_};
     bless( $self, ref($class) || $class );
-    return $self;
+    return $self
 }
 
-sub url($;$) {
+sub url {
     my $self = shift;
     if (@_) {
         $self->{'url'} = shift;
@@ -28,7 +27,7 @@ sub url($;$) {
     }
 }
 
-sub user($;$) {
+sub user {
     my $self = shift;
     if (@_) {
         $self->{'user'} = shift;
@@ -38,7 +37,7 @@ sub user($;$) {
     }
 }
 
-sub password($;$) {
+sub password {
     my $self = shift;
     if (@_) {
         $self->{'password'} = shift;
@@ -48,7 +47,7 @@ sub password($;$) {
     }
 }
 
-sub error($$;$$) {
+sub error {
     my ( $self, $message, $http_code, $xmlrpc_code ) = @_;
     require BZ::Client::Exception;
     BZ::Client::Exception->throw(
@@ -58,7 +57,7 @@ sub error($$;$$) {
     );
 }
 
-sub log($$$) {
+sub log {
     my ( $self, $level, $msg ) = @_;
     my $logger = $self->logger();
     if ($logger) {
@@ -66,7 +65,7 @@ sub log($$$) {
     }
 }
 
-sub logger($;$) {
+sub logger {
     my ($self) = shift;
     if (@_) {
         $self->{'logger'} = shift;
@@ -76,7 +75,7 @@ sub logger($;$) {
     }
 }
 
-sub logDirectory($;$) {
+sub logDirectory {
     my ($self) = shift;
     if (@_) {
         $self->{'logDirectory'} = shift;
@@ -86,7 +85,7 @@ sub logDirectory($;$) {
     }
 }
 
-sub xmlrpc($;$) {
+sub xmlrpc {
     my $self = shift;
     if (@_) {
         $self->{'xmlrpc'} = shift;
@@ -105,7 +104,7 @@ sub xmlrpc($;$) {
     }
 }
 
-sub login($) {
+sub login {
     my $self = shift;
     my $user = $self->user()
       or $self->error('The Bugzilla servers user name is not set.');
@@ -126,10 +125,10 @@ sub login($) {
     }
     $self->{'cookies'} = $cookies;
 
-    return;
+    return
 }
 
-sub logout($) {
+sub logout {
     my $self    = shift;
     my $cookies = $self->{'cookies'};
     if ($cookies) {
@@ -139,20 +138,20 @@ sub logout($) {
     }
 }
 
-sub is_logged_in($) {
+sub is_logged_in {
     my $self = shift;
-    return ( $self->{'cookies'} or $self->{'payload'} ) ? 1 : 0;
+    return ( $self->{'cookies'} or $self->{'payload'} ) ? 1 : 0
 }
 
-sub api_call($$$) {
+sub api_call {
     my ( $self, $methodName, $params ) = @_;
     if ( !$self->is_logged_in() ) {
         $self->login();
     }
-    return $self->_api_call( $methodName, $params );
+    return $self->_api_call( $methodName, $params )
 }
 
-sub _api_call($$$;$) {
+sub _api_call {
 
     my ( $self, $methodName, $params, $cookies ) = @_;
 
@@ -180,22 +179,30 @@ sub _api_call($$$;$) {
     $self->log( 'debug',
         "BZ::Client::_api_call, got response for method $methodName" );
 
-    return $response;
+    return $response
 }
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-  BZ::Client - A client for the Bugzilla web services API.
+BZ::Client - A client for the Bugzilla web services API.
+
+=head1 VERSION
+
+version 1.063
 
 =head1 SYNOPSIS
 
-  my $client = BZ::Client->new("url" => $url,
-                               "user" => $user,
-                               "password" => $password);
+  my $client = BZ::Client->new( url      => $url,
+                                user     => $user,
+                                password => $password );
   $client->login();
 
 =head1 CLASS METHODS
@@ -204,9 +211,9 @@ This section lists the class methods of BZ::Client.
 
 =head1 new
 
-  my $client = BZ::Client->new("url" => $url,
-                               "user" => $user,
-                               "password" => $password);
+  my $client = BZ::Client->new( url      => $url,
+                                user     => $user,
+                                password => $password );
 
 The new method constructs a new instance of BZ::Client. Whenever you
 want to connect to the Bugzilla server, you must first create a
@@ -241,14 +248,14 @@ perform.
 =head2 url
 
   my $url = $client->url();
-  $client->url($url);
+  $client->url( $url );
 
 Returns or sets the Bugzilla servers URL.
 
 =head2 user
 
   my $user = $client->user();
-  $client->user($user);
+  $client->user( $user );
 
 Returns or sets the user name to use when logging in to the Bugzilla
 server. Typically, this will be your email address.
@@ -256,7 +263,7 @@ server. Typically, this will be your email address.
 =head2 password
 
   my $password = $client->password();
-  $client->password($password);
+  $client->password( $password );
 
 Returns or sets the password to use when logging in to the Bugzilla server.
 
@@ -267,7 +274,7 @@ explicitly: It is done automatically, whenever required.
 
 =head2 api_call
 
-  my $response = $client->api_call($methodName, $params);
+  my $response = $client->api_call( $methodName, $params );
 
 Used by subclasses of L<BZ::Client::API> to invoke methods of the Bugzilla
 API. Takes a method name and a hash ref of parameters as input. Returns a
@@ -275,5 +282,27 @@ hash ref of named result objects.
 
 =head1 SEE ALSO
 
-  L<BZ::Client::Exception>
+L<BZ::Client::Exception>
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=item *
+
+Jochen Wiedmann <jochen.wiedmann@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
