@@ -1,33 +1,30 @@
 #!/bin/false
-
-#
-# BZ::Client::Bug - Client side representation of a bug in Bugzilla
-#
+# PODNAME: BZ::Client::Bug
+# ABSTRACT: Client side representation of a bug in Bugzilla
 
 use strict;
 use warnings 'all';
 
 package BZ::Client::Bug;
-
+$BZ::Client::Bug::VERSION = '1.063';
 use BZ::Client::API();
 
-our $VERSION = 1.0;
 our @ISA = qw(BZ::Client::API);
 
-sub legal_values($$$) {
+sub legal_values {
     my($class, $client, $field) = @_;
     $client->log('debug', "BZ::Client::Bug::legal_values: Asking for $field");
     my $params = { 'field' => $field };
     my $result = $class->api_call($client, 'Bug.legal_values', $params);
     my $values = $result->{'values'};
     if (!$values  ||  'ARRAY' ne ref($values)) {
-        $class->error($client, "Invalid reply by server, expected array of values.");
+        $class->error($client, 'Invalid reply by server, expected array of values.');
     }
     $client->log('debug', 'BZ::Client::Bug::legal_values: Got ' . join(',', @$values));
-    return $values;
+    return $values
 }
 
-sub get($$;$) {
+sub get {
     my($class, $client, $ids, $permissive) = @_;
     $client->log('debug', 'BZ::Client::Bug::get: Asking for ' . (ref($ids) eq 'ARRAY' ? join(',', @$ids) : $ids));
     my $params = { ids => $ids };
@@ -42,10 +39,10 @@ sub get($$;$) {
         push(@result, BZ::Client::Bug->new(%$bug));
     }
     $client->log('debug', 'BZ::Client::Bug::get: Got ' . scalar(@result));
-    return wantarray ? @result : \@result;
+    return wantarray ? @result : \@result
 }
 
-sub search($$$) {
+sub search {
     my($class, $client, $params) = @_;
     $client->log('debug', 'BZ::Client::Bug::search: Searching');
     my $result = $class->api_call($client, 'Bug.search', $params);
@@ -58,28 +55,28 @@ sub search($$$) {
         push(@result, BZ::Client::Bug->new(%$bug));
     }
     $client->log('debug', 'BZ::Client::Bug::search: Got ' . scalar(@result));
-    return wantarray ? @result : \@result;
+    return wantarray ? @result : \@result
 }
 
-sub create($$$) {
+sub create {
     my($class, $client, $params) = @_;
     $client->log('debug', 'BZ::Client::Bug::create: Creating');
-    my $result = $class->api_call($client, "Bug.create", $params);
-    my $id = $result->{"id"};
+    my $result = $class->api_call($client, 'Bug.create', $params);
+    my $id = $result->{'id'};
     if (!$id) {
         $class->error($client, 'Invalid reply by server, expected bug ID.');
     }
-    return $id;
+    return $id
 }
 
-sub new($@) {
+sub new {
     my $class = shift;
     my $self = { @_ };
     bless($self, ref($class) || $class);
-    return $self;
+    return $self
 }
 
-sub id($;$) {
+sub id {
     my $self = shift;
     if (@_) {
         $self->{'id'} = shift;
@@ -88,7 +85,7 @@ sub id($;$) {
     }
 }
 
-sub alias($;$) {
+sub alias {
     my $self = shift;
     if (@_) {
         $self->{'alias'} = shift;
@@ -97,7 +94,7 @@ sub alias($;$) {
     }
 }
 
-sub assigned_to($;$) {
+sub assigned_to {
     my $self = shift;
     if (@_) {
         $self->{'assigned_to'} = shift;
@@ -106,7 +103,7 @@ sub assigned_to($;$) {
     }
 }
 
-sub component($;$) {
+sub component {
     my $self = shift;
     if (@_) {
         $self->{'component'} = shift;
@@ -115,7 +112,7 @@ sub component($;$) {
     }
 }
 
-sub creation_time($;$) {
+sub creation_time {
     my $self = shift;
     if (@_) {
         $self->{'creation_time'} = shift;
@@ -124,7 +121,7 @@ sub creation_time($;$) {
     }
 }
 
-sub dupe_of($;$) {
+sub dupe_of {
     my $self = shift;
     if (@_) {
         $self->{'dupe_of'} = shift;
@@ -133,7 +130,7 @@ sub dupe_of($;$) {
     }
 }
 
-sub internals($;$) {
+sub internals {
     my $self = shift;
     if (@_) {
         $self->{'internals'} = shift;
@@ -142,7 +139,7 @@ sub internals($;$) {
     }
 }
 
-sub is_open($;$) {
+sub is_open {
     my $self = shift;
     if (@_) {
         $self->{'is_open'} = shift;
@@ -151,7 +148,7 @@ sub is_open($;$) {
     }
 }
 
-sub last_change_time($;$) {
+sub last_change_time {
     my $self = shift;
     if (@_) {
         $self->{'last_change_time'} = shift;
@@ -160,7 +157,7 @@ sub last_change_time($;$) {
     }
 }
 
-sub priority($;$) {
+sub priority {
     my $self = shift;
     if (@_) {
         $self->{'priority'} = shift;
@@ -169,7 +166,7 @@ sub priority($;$) {
     }
 }
 
-sub product($;$) {
+sub product {
     my $self = shift;
     if (@_) {
         $self->{'product'} = shift;
@@ -178,7 +175,7 @@ sub product($;$) {
     }
 }
 
-sub resolution($;$) {
+sub resolution {
     my $self = shift;
     if (@_) {
         $self->{'resolution'} = shift;
@@ -187,7 +184,7 @@ sub resolution($;$) {
     }
 }
 
-sub severity($;$) {
+sub severity {
     my $self = shift;
     if (@_) {
         $self->{'severity'} = shift;
@@ -196,7 +193,7 @@ sub severity($;$) {
     }
 }
 
-sub status($;$) {
+sub status {
     my $self = shift;
     if (@_) {
         $self->{'status'} = shift;
@@ -205,7 +202,7 @@ sub status($;$) {
     }
 }
 
-sub summary($;$) {
+sub summary {
     my $self = shift;
     if (@_) {
         $self->{'summary'} = shift;
@@ -216,21 +213,29 @@ sub summary($;$) {
 
 1;
 
+__END__
+
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
-  BZ::Client::Bug - Client side representation of a bug in Bugzilla
+BZ::Client::Bug - Client side representation of a bug in Bugzilla
 
-This class provides methods for accessing and managing bugs in Bugzilla.
+=head1 VERSION
 
+version 1.063
 
 =head1 SYNOPSIS
 
-  my $client = BZ::Client->new("url" => $url,
-                               "user" => $user,
-                               "password" => $password);
-  my $bugs = BZ::Client::Bug->get($client, $ids);
+This class provides methods for accessing and managing bugs in Bugzilla.
+
+  my $client = BZ::Client->new( url      => $url,
+                                user     => $user,
+                                password => $password );
+
+  my $bugs = BZ::Client::Bug->get( $client, $ids );
 
 =head1 CLASS METHODS
 
@@ -238,25 +243,25 @@ This section lists the class methods, which are available in this module.
 
 =head2 get
 
-  my $bugs = BZ::Client::Bug->get($client, $ids);
+  my $bugs = BZ::Client::Bug->get( $client, $ids );
 
 Returns a list of bug instances with the given ID's.
 
 =head2 new
 
-  my $bug = BZ::Client::Bug->new("id" => $id);
+  my $bug = BZ::Client::Bug->new( id => $id );
 
 Creates a new instance with the given ID.
 
 =head2 create
 
-  my $id = BZ::Client::Bug->create($client, $params);
+  my $id = BZ::Client::Bug->create( $client, $params );
 
 Creates a new bug and returns the bug ID.
 
 =head2 search
 
-  my $bugs = BZ::Client::Bug->search($client, $params);
+  my $bugs = BZ::Client::Bug->search( $client, $params );
 
 Searches for bugs matching the given parameters.
 
@@ -267,14 +272,14 @@ This section lists the modules instance methods.
 =head2 id
 
   my $id = $bug->id();
-  $bug->id($id);
+  $bug->id( $id );
 
 Gets or sets the bugs ID.
 
 =head2 alias
 
   my $alias = $bug->alias();
-  $bug->alias($alias);
+  $bug->alias( $alias );
 
 Gets or sets the bugs alias. If there is no alias or aliases are disabled in Bugzilla,
 this will be an empty string.
@@ -282,28 +287,28 @@ this will be an empty string.
 =head2 assigned_to
 
   my $assigned_to = $bug->assigned_to();
-  $bug->assigned_to($assigned_to);
+  $bug->assigned_to( $assigned_to );
 
 Gets or sets the login name of the user to whom the bug is assigned.
 
 =head2 component
 
   my $component = $bug->component();
-  $bug->component($component);
+  $bug->component( $component );
 
 Gets or sets the name of the current component of this bug.
 
 =head2 creation_time
 
   my $dateTime = $bug->creation_time();
-  $bug->creation_time($dateTime);
+  $bug->creation_time( $dateTime );
 
 Gets or sets the date and time, when the bug was created.
 
 =head2 dupe_of
 
   my $dupeOf = $bug->dupe_of();
-  $bug->dupe_of($dupeOf);
+  $bug->dupe_of( $dupeOf );
 
 Gets or sets the bug ID of the bug that this bug is a duplicate of. If this
 bug isn't a duplicate of any bug, this will be an empty int.
@@ -311,7 +316,7 @@ bug isn't a duplicate of any bug, this will be an empty int.
 =head2 is_open
 
   my $isOpen = $bug->is_open();
-  $bug->is_open($isOpen);
+  $bug->is_open( $isOpen );
 
 Gets or sets, whether this bug is closed. The return value, or parameter value
 is true (1) if this bug is open, false (0) if it is closed.
@@ -319,53 +324,75 @@ is true (1) if this bug is open, false (0) if it is closed.
 =head2 last_change_time
 
   my $lastChangeTime = $bug->last_change_time();
-  $bug->last_change_time($lastChangeTime);
+  $bug->last_change_time( $lastChangeTime );
 
 Gets or sets the date and time, when the bug was last changed.
 
 =head2 priority
 
   my $priority = $bug->priority();
-  $bug->priority($priority);
+  $bug->priority( $priority );
 
 Gets or sets the priority of the bug.
 
 =head2 product
 
   my $product = $bug->product();
-  $bug->product($product);
+  $bug->product( $product );
 
 Gets or sets the name of the product this bug is in.
 
 =head2 resolution
 
   my $resolution = $bug->resolution();
-  $bug->resolution($resolution);
+  $bug->resolution( $resolution );
 
 Gets or sets the current resolution of the bug, or an empty string if the bug is open.
 
 =head2 severity
 
   my $severity = $bug->severity();
-  $bug->severity($severity);
+  $bug->severity( $severity );
 
 Gets or sets the current severity of the bug.
 
 =head2 status
 
   my $status = $bug->status();
-  $bug->status($status);
+  $bug->status( $status );
 
 Gets or sets the current status of the bug.
 
 =head2 summary
 
   my $summary = $bug->summary();
-  $bug->summary($summary);
+  $bug->summary( $summary );
 
 Gets or sets the summary of this bug.
 
-
 =head1 SEE ALSO
 
   L<BZ::Client>, L<BZ::Client::API>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=item *
+
+Jochen Wiedmann <jochen.wiedmann@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
