@@ -1,18 +1,15 @@
 #!/bin/false
-
-#
-#  BZ::Client::Test - Module for writing integration tests
-#
+# PODNAME: BZ::Client::Test
+# ABSTRACT: Module for writing integration tests
 
 use strict;
 use warnings 'all';
 
 package BZ::Client::Test;
-
+$BZ::Client::Test::VERSION = '1.063';
 use BZ::Client();
 
-
-sub new($;@) {
+sub new {
     my $class = shift;
     my $self;
     if (@_ == 1) {
@@ -38,10 +35,10 @@ sub new($;@) {
         $self = { @_ };
     }
     bless($self, ref($class) || $class);
-    return $self;
+    return $self
 }
 
-sub testUrl($;$) {
+sub testUrl {
     my $self = shift;
     if (@_) {
         $self->{'testUrl'} = shift;
@@ -50,7 +47,7 @@ sub testUrl($;$) {
     }
 }
 
-sub testUser($;$) {
+sub testUser {
     my $self = shift;
     if (@_) {
         $self->{'testUser'} = shift;
@@ -59,7 +56,7 @@ sub testUser($;$) {
     }
 }
 
-sub testPassword($;$) {
+sub testPassword {
     my $self = shift;
     if (@_) {
         $self->{'testPassword'} = shift;
@@ -68,7 +65,7 @@ sub testPassword($;$) {
     }
 }
 
-sub logDirectory($;$) {
+sub logDirectory {
     my $self = shift;
     if (@_) {
         $self->{'logDirectory'} = shift;
@@ -77,39 +74,48 @@ sub logDirectory($;$) {
     }
 }
 
-sub client($) {
+sub client {
     my $self = shift;
     if ($self->isSkippingIntegrationTests()) {
-        die "Unable to create a client, as integration tests are being skipped.";
+        die 'Unable to create a client, as integration tests are being skipped.';
     }
-    return BZ::Client->new("url" => $self->testUrl(),
-                           "user" => $self->testUser(),
-                           "password" => $self->testPassword(),
-                           "logDirectory" => $self->logDirectory());
+    return BZ::Client->new( url  => $self->testUrl(),
+                            user  => $self->testUser(),
+                            password  => $self->testPassword(),
+                            logDirectory  => $self->logDirectory())
 }
 
-sub isSkippingIntegrationTests($) {
+sub isSkippingIntegrationTests {
     my $self = shift;
-    return !defined($self->testUrl());
+    return !defined($self->testUrl())
 }
 
 1;
 
+__END__
+
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
-  BZ::Client::Test - Module for writing integration tests
+BZ::Client::Test - Module for writing integration tests
+
+=head1 VERSION
+
+version 1.063
 
 =head1 SYNOPSIS
 
   # Create a new instance, reading configuration from either of
   # the given files.
-  my $tester = BZ::Client::Test->new(["config.pl", "t/config.pl"]);
+  my $tester = BZ::Client::Test->new(['config.pl', 't/config.pl']);
   my $skipping = $tester->isSkippingIntegrationTests();
   if ($skipping) {
     # Skip integration tests
-  } else {
+  }
+  else {
     my $client = $tester->client();
     # Run the tests, using the given client.
   }
@@ -122,12 +128,12 @@ This section lists the class methods.
 
   # Create a new instance, reading configuration from either of
   # the given files.
-  my $tester = BZ::Client::Test->new(["config.pl", "t/config.pl"]);
+  my $tester = BZ::Client::Test->new(['config.pl', 't/config.pl']);
 
   # Create a new instance, providing configuration explicitly.
-  my $tester = BZ::Client->new("testUrl" => $url,
-                               "testUser" => $user,
-                               "testPassword" => $password);
+  my $tester = BZ::Client->new( 'testUrl'      => $url,
+                                'testUser'     => $user,
+                                'testPassword' => $password);
 
 Creates a new instance with a configuration for running integration
 tests. The configuration can be read from a config file or be
@@ -148,7 +154,7 @@ an undefined value.
 =head2 testUrl
 
   my $url = $tester->testUrl();
-  $tester->testUrl($url);
+  $tester->testUrl( $url );
 
 Gets or sets the Bugzilla servers URL. This is also used to
 determine, whether the tester is able to run integration tests
@@ -158,14 +164,14 @@ be skipped.
 =head2 testUser
 
   my $user = $tester->testUser();
-  $tester->testUser($user);
+  $tester->testUser( $user );
 
 Gets or sets the Bugzilla servers user.
 
 =head2 testPassword
 
   my $password = $tester->testPassword();
-  $tester->testPassword($password);
+  $tester->testPassword( $password );
 
 Gets or sets the Bugzilla servers password.
 
@@ -177,8 +183,29 @@ Creates an instance of BZ::Client, using the testers configuration.
 An exception is thrown, if the tester is unable to create a client
 object, because integration tests are being skipped.
 
-
 =head1 SEE ALSO
 
   L<BZ::Client>
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=item *
+
+Jochen Wiedmann <jochen.wiedmann@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
