@@ -1,14 +1,12 @@
 #!/bin/false
-
-#
-# BZ::Client::XMLRPC.pm - Performs XML-RPC calls on behalf of the client.
-#
+# PODNAME: BZ::Client::XMLRPC
+# ABSTRACT: Performs XML-RPC calls on behalf of the client.
 
 use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC;
-
+$BZ::Client::XMLRPC::VERSION = '1.063';
 use LWP();
 use XML::Writer();
 use Encode;
@@ -16,20 +14,19 @@ use BZ::Client::XMLRPC::Parser();
 use DateTime::Format::Strptime();
 use DateTime::TimeZone();
 
-our $VERSION = 1.02;
 our $counter;
-our $fmt = DateTime::Format::Strptime->new(pattern=> '%C%Y-%m-%dT%T', time_zone=>'UTC');
-our $tz = DateTime::TimeZone->new(name => 'UTC');
+our $fmt = DateTime::Format::Strptime->new( pattern=> '%C%Y-%m-%dT%T', time_zone => 'UTC' );
+our $tz = DateTime::TimeZone->new( name => 'UTC' );
 
 
-sub new($%) {
+sub new {
     my $class = shift;
     my $self = { @_ };
     bless($self, ref($class) || $class);
     return $self;
 }
 
-sub url($;$) {
+sub url {
     my $self = shift;
     if (@_) {
         $self->{'url'} = shift;
@@ -38,7 +35,7 @@ sub url($;$) {
     }
 }
 
-sub user_agent($;$) {
+sub user_agent {
     my $self = shift;
     if (@_) {
         $self->{'user_agent'} = shift;
@@ -46,22 +43,22 @@ sub user_agent($;$) {
         my $ua = $self->{'user_agent'};
         if (!defined($ua)) {
             $ua = LWP::UserAgent->new();
-            $ua->agent("BZ::Client::XMLRPC $VERSION");
+            $ua->agent("BZ::Client::XMLRPC $BZ::Client::XMLRPC::VERSION");
             $self->user_agent($ua);
         }
         return $ua;
     }
 }
 
-sub error($$;$$) {
+sub error {
     my($self, $message, $http_code, $xmlrpc_code) = @_;
     require BZ::Client::Exception;
     BZ::Client::Exception->throw('message' => $message,
                                  'http_code' => $http_code,
-                                 'xmlrpc_code' => $xmlrpc_code);
+                                 'xmlrpc_code' => $xmlrpc_code)
 }
 
-sub value($$$) {
+sub value {
     my($self, $writer, $value) = @_;
     if (ref($value) eq 'HASH') {
         $writer->startTag('value');
@@ -120,7 +117,7 @@ sub value($$$) {
     }
 }
 
-sub create_request($$$) {
+sub create_request {
     my($self, $methodName, $params) = @_;
     my $contents;
     my $writer = XML::Writer->new(OUTPUT => \$contents, ENCODING => 'UTF-8');
@@ -137,17 +134,17 @@ sub create_request($$$) {
     $writer->endTag('params');
     $writer->endTag('methodCall');
     $writer->end();
-    return encode('utf8', $contents);
+    return encode('utf8', $contents)
 }
 
-sub get_response($$) {
+sub get_response {
     my($self, $contents) = @_;
     return _get_response($self, { 'url' => $self->url() . '/xmlrpc.cgi',
                                   'contentType' => 'text/xml',
-                                  'contents' => encode_utf8($contents) });
+                                  'contents' => encode_utf8($contents) })
 }
 
-sub _get_response($$) {
+sub _get_response {
     my($self, $params) = @_;
     my $url = $params->{'url'};
     my $contentType = $params->{'contentType'};
@@ -174,15 +171,15 @@ sub _get_response($$) {
         require File::Spec;
         my $fileName = File::Spec->catfile($logDir, "$$.$logId.request.log");
         if (open(my $fh, '>', $fileName)) {
-	    for my $header ($req->header_field_names()) {
-		for my $value ($req->header($header)) {
-		    print $fh "$header: $value\n";
-		}
-	    }
-	    if ($ua->cookie_jar()) {
-		print $fh $ua->cookie_jar()->as_string();
-	    }
-	    print $fh "\n";
+            for my $header ($req->header_field_names()) {
+                for my $value ($req->header($header)) {
+                    print $fh "$header: $value\n";
+                }
+            }
+            if ($ua->cookie_jar()) {
+                print $fh $ua->cookie_jar()->as_string();
+            }
+            print $fh "\n";
             print $fh $contents;
             close($fh);
         }
@@ -193,15 +190,15 @@ sub _get_response($$) {
     if ($logDir) {
         my $fileName = File::Spec->catfile($logDir, "$$.$logId.response.log");
         if (open(my $fh, '>', $fileName)) {
-	    for my $header ($res->header_field_names()) {
-		for my $value ($res->header($header)) {
-		    print $fh "$header: $value\n";
-		}
-	    }
-	    print $fh "\n";
-	    if ($res->is_success) {
-		print $fh $response;
-	    }
+            for my $header ($res->header_field_names()) {
+                for my $value ($res->header($header)) {
+                    print $fh "$header: $value\n";
+                }
+            }
+            print $fh "\n";
+            if ($res->is_success) {
+                print $fh $response;
+            }
             close($fh);
         }
     }
@@ -217,16 +214,16 @@ sub _get_response($$) {
         }
     }
 
-    return $response;
+    return $response
 }
 
-sub parse_response($$) {
+sub parse_response {
     my($self, $contents) = @_;
     my $parser = BZ::Client::XMLRPC::Parser->new();
-    return $parser->parse($contents);
+    return $parser->parse($contents)
 }
 
-sub request($%) {
+sub request {
     my $self = shift;
     my %args = @_;
     my $methodName = $args{'methodName'};
@@ -238,10 +235,10 @@ sub request($%) {
     $self->log('debug', "BZ::Client::XMLRPC::request: Sending method $methodName to " . $self->url());
     my $response = $self->get_response($contents);
     $self->log('debug', "BZ::Client::XMLRPC::request: Got result for method $methodName");
-    return $self->parse_response($response);
+    return $self->parse_response($response)
 }
 
-sub log($$$) {
+sub log {
     my($self, $level, $msg) = @_;
     my $logger = $self->logger();
     if ($logger) {
@@ -249,7 +246,7 @@ sub log($$$) {
     }
 }
 
-sub logger($;$) {
+sub logger {
     my($self) = shift;
     if (@_) {
         $self->{'logger'} = shift;
@@ -258,7 +255,7 @@ sub logger($;$) {
     }
 }
 
-sub logDirectory($;$) {
+sub logDirectory {
     my($self) = shift;
     if (@_) {
         $self->{'logDirectory'} = shift;
@@ -268,41 +265,49 @@ sub logDirectory($;$) {
 }
 
 package BZ::Client::XMLRPC::int;
-
-sub new($$) {
+$BZ::Client::XMLRPC::int::VERSION = '1.063';
+sub new {
     my($class, $value) = @_;
-    return bless(\$value, (ref($class) || $class));
+    return bless(\$value, (ref($class) || $class))
 }
 
 package BZ::Client::XMLRPC::boolean;
-
-sub new($$) {
+$BZ::Client::XMLRPC::boolean::VERSION = '1.063';
+sub new {
     my($class, $value) = @_;
-    return bless(\$value, (ref($class) || $class));
+    return bless(\$value, (ref($class) || $class))
 }
 
 use constant TRUE => BZ::Client::XMLRPC::boolean->new(1);
 use constant FALSE => BZ::Client::XMLRPC::boolean->new(0);
 
 package BZ::Client::XMLRPC::double;
-
-sub new($$) {
+$BZ::Client::XMLRPC::double::VERSION = '1.063';
+sub new {
     my($class, $value) = @_;
-    return bless(\$value, (ref($class) || $class));
+    return bless(\$value, (ref($class) || $class))
 }
 
 1;
 
+__END__
+
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
-  BZ::Client::XMLRPC - Performs XML-RPC calls on behalf of the client.
+BZ::Client::XMLRPC - Performs XML-RPC calls on behalf of the client.
+
+=head1 VERSION
+
+version 1.063
 
 =head1 SYNOPSIS
 
-  my $xmlrpc = BZ::Client::XMLRPC->new('url' => $url);
-  my $result = $xmlrpc->request('methodName' => $methodName, 'params' => $params);
+  my $xmlrpc = BZ::Client::XMLRPC->new( url => $url );
+  my $result = $xmlrpc->request( methodName => $methodName, params => $params );
 
 An instance of BZ::Client::XMLRPC is able to perform XML-RPC calls against the
 given URL. A request is performed by passing the method name and the method
@@ -314,7 +319,7 @@ This section lists the possible class methods.
 
 =head2 new
 
-  my $xmlrpc = BZ::Client::XMLRPC->new('url' => $url);
+  my $xmlrpc = BZ::Client::XMLRPC->new( url => $url );
 
 Creates a new instance with the given URL.
 
@@ -325,13 +330,13 @@ This section lists the possible instance methods.
 =head2 url
 
   my $url = $xmlrpc->url();
-  $xmlrpc->url($url);
+  $xmlrpc->url( $url );
 
 Returns or sets the XML-RPC servers URL.
 
 =head2 request
 
-  my $result = $xmlrpc->request('methodName' => $methodName, 'params' => $params);
+  my $result = $xmlrpc->request( methodName => $methodName, params => $params );
 
 Calls the XML-RPC servers method C<$methodCall>, passing the parameters given by
 C<$params>, an array of parameters. Parameters may be hash refs, array refs, or
@@ -342,3 +347,26 @@ errors.
 =head1 SEE ALSO
 
   L<BZ::Client>, L<BZ::Client::Exception>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=item *
+
+Jochen Wiedmann <jochen.wiedmann@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
