@@ -1,35 +1,35 @@
-#
-# BZ::Client::XMLRPC::Array - Event handler for parsing a single XML-RPC array.
-#
-package BZ::Client::XMLRPC::Array;
+#!/bin/false
+# PODNAME: BZ::Client::XMLRPC::Array
+# ABSTRACT: Event handler for parsing a single XML-RPC array.
 
 use strict;
-use warnings "all";
+use warnings 'all';
 
-use BZ::Client::XMLRPC::Handler();
+package BZ::Client::XMLRPC::Array;
+$BZ::Client::XMLRPC::Array::VERSION = '1.063';
+use BZ::Client::XMLRPC::Handler ();
 
-our $VERSION = 1.0;
 our @ISA = qw(BZ::Client::XMLRPC::Handler);
 
-sub init($$) {
+sub init {
     my($self,$parser) = @_;
     $self->SUPER::init($parser);
-    $self->{'result'} = [];
+    $self->{'result'} = []
 }
 
-sub start($$) {
+sub start {
     my($self,$name) = @_;
     my $l = $self->inc_level();
     if ($l == 0) {
-        if ("array" ne $name) {
+        if ('array' ne $name) {
             $self->error("Expected array element, got $name");
         }
     } elsif ($l == 1) {
-        if ("data" ne $name) {
+        if ('data' ne $name) {
             $self->error("Expected array/data element, got $name");
         }
     } elsif ($l == 2) {
-        if ("value" eq $name) {
+        if ('value' eq $name) {
             my $handler = BZ::Client::XMLRPC::Value->new();
             $self->parser()->register($self, $handler, sub {
                 my $array = $self->{'result'};
@@ -43,12 +43,49 @@ sub start($$) {
     } else {
         $self->error("Unexpected level $l with element $name");
     }
-    return $l;
+    return $l
 }
 
-sub result($) {
-    my($self) = shift;
-    return $self->{'result'};
+sub result {
+    my $self = shift;
+    return $self->{'result'}
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+BZ::Client::XMLRPC::Array - Event handler for parsing a single XML-RPC array.
+
+=head1 VERSION
+
+version 1.063
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=item *
+
+Jochen Wiedmann <jochen.wiedmann@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
