@@ -1,27 +1,25 @@
-#
-# BZ::Client::XMLRPC::Handler - Abstract event handler for parsing an XML-RPC response.
-#
-package BZ::Client::XMLRPC::Handler;
-
+#!/bin/false
+# PODNAME: BZ::Client::XMLRPC::Handler
+# ABSTRACT: Abstract event handler for parsing an XML-RPC response.
 use strict;
-use warnings "all";
+use warnings 'all';
 
-our $VERSION = 1.0;
-
-sub new ($%) {
+package BZ::Client::XMLRPC::Handler;
+$BZ::Client::XMLRPC::Handler::VERSION = '1.063';
+sub new {
     my $class = shift;
     my $self = { @_ };
     $self->{'level'} = 0;
     bless($self, ref($class) || $class);
-    return $self;
+    return $self
 }
 
-sub init($$) {
+sub init {
     my($self,$parser) = @_;
     $self->parser($parser);
 }
 
-sub parser($;$) {
+sub parser {
     my $self = shift;
     if (@_) {
         $self->{'parser'} = shift;
@@ -30,7 +28,7 @@ sub parser($;$) {
     }
 }
 
-sub level($;$) {
+sub level {
     my $self = shift;
     if (@_) {
         $self->{'level'} = shift;
@@ -39,37 +37,75 @@ sub level($;$) {
     }
 }
 
-sub inc_level($) {
+sub inc_level {
     my $self = shift;
     my $res = $self->{'level'}++;
-    return $res;
+    return $res
 }
 
-sub dec_level($) {
+sub dec_level {
     my $self = shift;
     my $res = --$self->{'level'};
-    return $res;
+    return $res
 }
 
-sub error($$) {
+sub error {
     my($self, $msg) = @_;
     $self->parser()->error($msg);
 }
 
-sub characters($$) {
+sub characters {
     my($self, $text) = @_;
     if ($text !~ /^\s*$/s) {
         $self->error("Unexpected non-whitespace: $text");
     }
 }
 
-sub end($$) {
-    my($self,$name) = @_;
+sub end {
+    # my($self,$name) = @_;
+    my $self = shift;
     my $l = $self->dec_level();
     if ($l == 0) {
         $self->parser()->remove($self);
     }
-    return $l;
+    return $l
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+BZ::Client::XMLRPC::Handler - Abstract event handler for parsing an XML-RPC response.
+
+=head1 VERSION
+
+version 1.063
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=item *
+
+Jochen Wiedmann <jochen.wiedmann@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
