@@ -1,20 +1,20 @@
-#
-# BZ::Client::XMLRPC::Value - Event handler for parsing a single XML-RPC value.
-#
-package BZ::Client::XMLRPC::Value;
+#!/bin/false
+# PODNAME: BZ::Client::XMLRPC::Value
+# ABSTRACT: Event handler for parsing a single XML-RPC value.
 
 use strict;
 use warnings 'all';
 
-use BZ::Client::XMLRPC::Handler();
-use BZ::Client::XMLRPC::Struct();
-use BZ::Client::XMLRPC::Array();
-use DateTime::Format::ISO8601();
+package BZ::Client::XMLRPC::Value;
+$BZ::Client::XMLRPC::Value::VERSION = '1.063';
+use BZ::Client::XMLRPC::Handler ();
+use BZ::Client::XMLRPC::Struct ();
+use BZ::Client::XMLRPC::Array ();
+use DateTime::Format::ISO8601 ();
 
-our $VERSION = 1.01;
-our @ISA     = qw(BZ::Client::XMLRPC::Handler);
+our @ISA = qw(BZ::Client::XMLRPC::Handler);
 
-sub start($$) {
+sub start {
     my ( $self, $name ) = @_;
     my $l = $self->inc_level();
     if ( $l == 0 ) {
@@ -44,7 +44,7 @@ sub start($$) {
             );
             $handler->start($name);
         }
-        elsif ('i4' eq $name
+        elsif ('i4'               eq $name
             || 'int'              eq $name
             || 'string'           eq $name
             || 'double'           eq $name
@@ -53,7 +53,7 @@ sub start($$) {
             || 'boolean'          eq $name )
         {
             $self->{'level1_elem'}    = $name;
-            $self->{'level1_content'} = "";
+            $self->{'level1_content'} = q();
         }
         else {
             $self->error(
@@ -66,7 +66,7 @@ sub start($$) {
     }
 }
 
-sub end($$) {
+sub end {
     my ( $self, $name ) = @_;
     my $l = $self->level();
     if ( $l == 1 ) {
@@ -97,31 +97,68 @@ sub end($$) {
             }
         }
     }
-    return $self->SUPER::end($name);
+    return $self->SUPER::end($name)
 }
 
-sub characters($$) {
+sub characters {
     my ( $self, $text ) = @_;
     my $l = $self->level();
     if ( $l == 1 ) {
         $self->{'level0_content'} .= $text;
-        return;
+        return
     }
     elsif ( $l == 2 ) {
         my $l1_elem = $self->{'level1_elem'};
         if ( defined($l1_elem) ) {
             $self->{'level1_content'} .= $text;
-            return;
+            return
         }
     }
     $self->SUPER::characters($text);
 }
 
-sub result($) {
-    my ($self) = shift;
+sub result {
+    my $self = shift;
     my $res = $self->{'result'};
-    $res = defined($res) ? $res : "";
-    return $res;
+    $res = defined($res) ? $res : q();
+    return $res
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+BZ::Client::XMLRPC::Value - Event handler for parsing a single XML-RPC value.
+
+=head1 VERSION
+
+version 1.063
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=item *
+
+Jochen Wiedmann <jochen.wiedmann@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
